@@ -60,6 +60,7 @@ Examples:
     pyqsp --plot --func "np.cos(3*x)" --polydeg 6 polyfunc
     pyqsp --plot --func "np.cos(3*x)" --polydeg 6 --plot-qsp-model polyfunc
     pyqsp --plot-positive-only --plot-real-only --plot --polyargs 20,3.5 --polyname gibbs --plot-qsp-model poly
+    pyqsp --polydeg 16 --measurement="z" --func="-1+np.sign(1/np.sqrt(2)-x)+ np.sign(1/np.sqrt(2)+x)" --plot polyfunc
 
 """.format(version)
 
@@ -161,6 +162,16 @@ Examples:
         "--plot-real-only",
         help="when plotting only real component, and not imaginary",
         action="store_true")
+    parser.add_argument(
+        "--title",
+        help="plot title",
+        type=str,
+        default=None)
+    parser.add_argument(
+        "--measurement",
+        help="measurement basis if using the polyfunc argument",
+        type=str,
+        default=None)
     parser.add_argument(
         "--output-json",
         help="output QSP phase angles in JSON format",
@@ -177,7 +188,7 @@ Examples:
         "--plot-npts",
         help="number of points to use in plotting",
         type=int,
-        default=100)
+        default=400)
     parser.add_argument(
         "--tolerance",
         help="error tolerance for phase angle optimizer",
@@ -227,7 +238,7 @@ Examples:
                      tolerance=args.tolerance,
                      nepochs=args.nepochs,
                      npts_theta=args.npts_theta,
-    )
+                     )
 
     if args.cmd == "poly2angles":
         coefs = args.poly
@@ -392,6 +403,23 @@ Examples:
                 title="Threshold Function",
                 **plot_args)
 
+    elif args.cmd == "poly_phase":
+        pg = pyqsp.poly.PolyPhaseEstimation()
+        pcoefs, scale = pg.generate(
+            *args.seqargs,
+            ensure_bounded=True,
+            return_scale=True)
+        phiset = angle_sequence.QuantumSignalProcessingPhases(
+            pcoefs, **qspp_args)
+        if args.plot:
+            response.PlotQSPResponse(
+                phiset,
+                target=lambda x: scale *
+                (-1 + np.sign(1/np.sqrt(2) - x) + np.sign(1/np.sqrt(2) + x)),
+                signal_operator="Wx",
+                title="Phase Estimation Polynomial",
+                **plot_args)
+
     elif args.cmd == "poly_rect":
         pg = pyqsp.poly.PolyRect()
         pcoefs, scale = pg.generate(
@@ -471,10 +499,17 @@ Examples:
         qspp_args['method'] = 'tf'
         poly = StringPolynomial(args.func, args.polydeg)
         phiset = angle_sequence.QuantumSignalProcessingPhases(
-            poly, **qspp_args)
+            poly,
+            measurement=args.measurement,
+            **qspp_args)
         if args.plot:
             response.PlotQSPResponse(
-                phiset, target=poly, signal_operator="Wx", **plot_args)
+                phiset,
+                target=poly,
+                signal_operator="Wx",
+                measurement=args.measurement,
+                title=args.title,
+                **plot_args)
 
     elif args.cmd == "response":
         if not args.phiset:
